@@ -1,4 +1,4 @@
-def print_signature() -> str:
+def print_signature() -> None:
     print("""-----BEGIN PGP SIGNED MESSAGE-----
 Hash: SHA512
 
